from django.core.management.base import BaseCommand

from arkindex.dataimport.models import Repository


class Command(BaseCommand):
    help = "Update all Git repositories references and trigger build processes"

    def add_arguments(self, parser):
        parser.add_argument(
            "--repo-url",
            type=str,
            help="Limit process to one repository",
        )

    def handle(self, repo_url, *args, **kwargs):

        repositories = Repository.objects.all()
        if repo_url:
            repositories = repositories.filter(url=repo_url)

        for repository in repositories:

            self.stdout.write(f"Updating refs for {repository}")

            # List all refs
            try:
                repository.provider.update_repository_references(repository)
            except Exception as e:
                self.stderr.write(f"Failure for {repository}: {e}")

        self.stdout.write("All done")
