from django.core.management import call_command

from arkindex.dataimport.models import WorkerVersion
from arkindex.project.tests import FixtureTestCase


class TestCacheWorkerVersions(FixtureTestCase):

    @classmethod
    def setUpTestData(cls):
        super().setUpTestData()
        cls.dla, cls.recognizer = WorkerVersion.objects.get(worker__slug='dla'), WorkerVersion.objects.get(worker__slug='reco')

    def test_run(self):
        self.corpus.worker_versions.add(self.dla)
        self.assertCountEqual(list(self.corpus.worker_versions.all()), [self.dla])
        call_command('cache_worker_versions')
        self.assertCountEqual(list(self.corpus.worker_versions.all()), [self.dla, self.recognizer])

    def test_drop(self):
        self.corpus.worker_versions.add(self.dla)
        self.assertCountEqual(list(self.corpus.worker_versions.all()), [self.dla])
        call_command('cache_worker_versions', drop=True)
        self.assertCountEqual(list(self.corpus.worker_versions.all()), [self.recognizer])

    def test_ignore_conflicts(self):
        self.corpus.worker_versions.add(self.recognizer)
        self.assertCountEqual(list(self.corpus.worker_versions.all()), [self.recognizer])
        call_command('cache_worker_versions')
        self.assertCountEqual(list(self.corpus.worker_versions.all()), [self.recognizer])
