from django.db import IntegrityError

from arkindex.project.tests import FixtureTestCase


class TestPathConstraints(FixtureTestCase):

    def test_unique_paths(self):
        """
        Ensure an Element cannot have strictly the same paths twice
        """
        element_type = self.corpus.types.first()
        parent1 = self.corpus.elements.get(name='Volume 1')
        parent2 = self.corpus.elements.get(name='Volume 2')
        element = self.corpus.elements.create(
            type=element_type,
            name='Test element',
        )
        child = self.corpus.elements.create(
            type=element_type,
            name='Test child',
        )

        element.add_parent(parent1)
        element.add_parent(parent2)

        child.add_parent(element)
        self.assertCountEqual(child.paths.values_list('path', 'ordering'), [
            ([parent1.id, element.id], 0),
            ([parent2.id, element.id], 0)
        ])

        # Cannot create a path that already exists
        with self.assertRaises(IntegrityError):
            child.paths.create(path=[parent1.id, element.id], ordering=42)
