# Generated by Django 3.1.7 on 2021-05-04 09:10

import django.utils.timezone
from django.contrib.contenttypes.models import ContentType
from django.db import migrations, models

from arkindex.users.models import Role


def update_creation_date(apps, schema_editor):
    """
    Update User creation date to his "My Project" creation date (when the project is available)
    instead of default timezone.now
    """
    db_alias = schema_editor.connection.alias
    Corpus = apps.get_model('documents', 'Corpus')
    corpus_content_type = ContentType.objects.get_for_model(Corpus)
    Right = apps.get_model('users', 'Right')
    User = apps.get_model('users', 'User')

    to_update = []
    corpora = Corpus.objects.using(db_alias).filter(name='My Project')
    for corpus in corpora:
        try:
            admin = Right.objects.using(db_alias).filter(content_type=corpus_content_type.id, content_id=corpus.id).get(level__gte=Role.Admin.value, user__isnull=False).user
            admin.created = corpus.created
            to_update.append(admin)
        except (Right.DoesNotExist, Right.MultipleObjectsReturned):
            continue
    User.objects.using(db_alias).bulk_update(to_update, ['created'])


class Migration(migrations.Migration):

    dependencies = [
        ('users', '0012_drop_corpus_right'),
    ]

    operations = [
        migrations.AddField(
            model_name='user',
            name='created',
            field=models.DateTimeField(auto_now_add=True, default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='user',
            name='updated',
            field=models.DateTimeField(auto_now=True),
        ),
        migrations.RunPython(
            update_creation_date,
            reverse_code=migrations.RunPython.noop,
        )
    ]
